@@ -61,11 +61,6 @@ public:
 
 App::App(QWidget * parent)
     : KXmlGuiWindow(parent)
-    , m_gameTipLabel(nullptr)
-    , m_gameTimerLabel(nullptr)
-    , m_gameTilesLabel(nullptr)
-    , m_gameCheatLabel(nullptr)
-    , m_board(nullptr)
 {
     m_board = new Board(this);
     m_board->setObjectName(QStringLiteral("board"));
@@ -103,7 +98,7 @@ void App::setupActions()
     KStandardGameAction::gameNew(this, &App::invokeNewGame, actionCollection());
     KStandardGameAction::restart(this, &App::restartGame, actionCollection());
     KStandardGameAction::pause(this, &App::togglePause, actionCollection());
-    KStandardGameAction::highscores(this, &App::showHighscores, actionCollection());
+    KStandardGameAction::highscores(this, &App::showHighScores, actionCollection());
     KStandardGameAction::quit(this, &App::close, actionCollection());
 
     // Move
@@ -261,7 +256,7 @@ void App::slotEndOfGame()
         scoreDialog->setConfigGroup(qMakePair(QByteArray(configGroup.toUtf8()), configGroup));
 
         if (m_board->hasCheated()) {
-            auto const message = i18n("\nYou could have been in the highscores\nif you did not use Undo or Hint.\nTry without them next time.");
+            auto const message = i18n("\nYou could have been in the high scores\nif you did not use Undo or Hint.\nTry without them next time.");
             KMessageBox::information(this, message, i18n("End of Game"));
         } else {
             if (scoreDialog->addScore(scoreInfo) > 0) {
@@ -305,18 +300,16 @@ void App::updateCheatDisplay()
     m_gameCheatLabel->setVisible(m_board->hasCheated());
 }
 
-int App::score(int x, int y, int seconds, bool gravity) const
+int App::score(int x, int y, int seconds, bool gravity)
 {
-    auto const ntiles = static_cast<double>(x * y);
-    auto const tilespersec = ntiles / static_cast<double>(seconds);
+    auto const nTiles = static_cast<double>(x * y);
+    auto const tilesPerSec = nTiles / static_cast<double>(seconds);
 
-    auto const sizebonus = std::sqrt(ntiles / static_cast<double>(14.0 * 6.0));
-    auto const points = tilespersec / 0.14 * 100.0;
+    auto const sizeBonus = std::sqrt(nTiles / 14.0 * 6.0);
+    auto const points = tilesPerSec / 0.14 * 100.0;
+    auto const gravityBonus = gravity ? 2.0 : 1.0;
 
-    if (gravity) {
-        return static_cast<int>(2.0 * points * sizebonus);
-    }
-    return static_cast<int>(points * sizebonus);
+    return static_cast<int>(points * sizeBonus * gravityBonus);
 }
 
 void App::notifySelectATile()
@@ -350,7 +343,7 @@ void App::setCheatModeEnabled(bool enabled)
     m_gameCheatLabel->setVisible(enabled);
 }
 
-void App::showHighscores()
+void App::showHighScores()
 {
     KScoreDialog scoreDialog(KScoreDialog::Name | KScoreDialog::Time, this);
     scoreDialog.addField(KScoreDialog::Custom1, i18n("Gravity"), QStringLiteral("gravity"));
@@ -370,7 +363,7 @@ void App::showSettingsDialog()
         return;
     }
 
-    //Use the classes exposed by LibKmahjongg for our configuration dialog
+    //Use the classes exposed by LibKMahjongg for our configuration dialog
     auto dialog = new KMahjonggConfigDialog(this, QStringLiteral("settings"), Prefs::self());
     dialog->addPage(new Settings(nullptr), i18n("General"), QStringLiteral("games-config-options"));
     dialog->addTilesetPage();
@@ -381,5 +374,7 @@ void App::showSettingsDialog()
 }
 } // namespace KShisen
 
+#include "moc_app.cpp"
+
 // vim: expandtab:tabstop=4:shiftwidth=4
 // kate: space-indent on; indent-width 4
