@@ -89,13 +89,13 @@ private Q_SLOTS:
 
     /** Shows a hint and sets cheat flag.
      * The Hint action should set the cheat flag, so the user cannot end up in
-     * the highscore dialog by having been told what to do. :)
+     * the high score dialog by having been told what to do. :)
      */
     void hint();
-    /// Calls showHighscore without arguments
+    /// Calls KShortcutsDialog without arguments
     void keyBindings();
-    /// Shows the highscore table
-    void showHighscores(); // const?
+    /// Shows the high score table
+    void showHighScores(); // const?
 
 Q_SIGNALS:
     /** Invokes the creation of a new game.
@@ -109,7 +109,7 @@ Q_SIGNALS:
 
 private:
     /// Calculates the scores
-    int score(int x, int y, int seconds, bool gravity) const;
+    static int score(int x, int y, int seconds, bool gravity);
 
     /** Sets up the status bar areas.
      * There are four areas in the status bar:
@@ -125,11 +125,11 @@ private:
     void setCheatModeEnabled(bool enabled);
 
 private:
-    QLabel * m_gameTipLabel; ///< Status bar area for game tips
-    QLabel * m_gameTimerLabel; ///< Status bar area for the timer
-    QLabel * m_gameTilesLabel; ///< Status bar area for the tile counter
-    QLabel * m_gameCheatLabel; ///< Status bar area for the cheat mode
-    Board * m_board; ///< Holds the game board
+    QLabel * m_gameTipLabel{nullptr}; ///< Status bar area for game tips
+    QLabel * m_gameTimerLabel{nullptr}; ///< Status bar area for the timer
+    QLabel * m_gameTilesLabel{nullptr}; ///< Status bar area for the tile counter
+    QLabel * m_gameCheatLabel{nullptr}; ///< Status bar area for the cheat mode
+    Board * m_board{nullptr}; ///< Holds the game board
 };
 } // namespace KShisen
 
