@@ -34,41 +34,13 @@ namespace KShisen
 #define SEASONS_START 28
 #define FLOWERS_START 39
 
-static std::array<int, 5> constexpr s_delay {{1000, 750, 500, 250, 125}};
-static std::array<int, 6> constexpr s_sizeX {{14, 16, 18, 24, 26, 30}};
-static std::array<int, 6> constexpr s_sizeY {{6, 9, 8, 12, 14, 16}};
+static std::array constexpr s_delay {1000, 750, 500, 250, 125};
+static std::array constexpr s_sizeX {14, 16, 18, 24, 26, 30};
+static std::array constexpr s_sizeY {6, 9, 8, 12, 14, 16};
 
 Board::Board(QWidget * parent)
     : QWidget(parent)
-    , m_gameClock()
-    , m_tiles()
-    , m_background()
     , m_random(QRandomGenerator::global()->generate())
-    , m_undo()
-    , m_redo()
-    , m_markX(0)
-    , m_markY(0)
-    , m_connection()
-    , m_possibleMoves()
-    , m_field()
-    , m_xTiles(0)
-    , m_yTiles(0)
-    , m_delay(0)
-    , m_level(0)
-    , m_shuffle(0)
-    , m_gameState(GameState::Normal)
-    , m_cheat(false)
-    , m_gravityFlag(true)
-    , m_solvableFlag(false)
-    , m_showUnsolvableMessageFlag(false)
-    , m_chineseStyleFlag(false)
-    , m_tilesCanSlideFlag(false)
-    , m_highlightedTile(-1)
-    , m_paintConnection(false)
-    , m_paintPossibleMoves(false)
-    , m_paintInProgress(false)
-    , m_tileRemove1()
-    , m_tileRemove2()
     , m_soundPick(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds/kshisen/tile-touch.ogg")))
     , m_soundFall(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds/kshisen/tile-fall-tile.ogg")))
 {
@@ -94,22 +66,22 @@ void Board::loadSettings()
                 // we're good the default was loaded
             } else {
                 KMessageBox::error(this
-                    , i18nc("%1 is a path to a tileset file", "An error occurred when loading the default tileset.\nPlease install the KMahjongg library.")
+                    , i18nc("%1 is a path to a tile set file", "An error occurred when loading the default tile set.\nPlease install the KMahjongg library.")
                     , i18n("Error Loading Tiles")
                 );
             }
         } else {
-            // This is when there was a tileset and has disappear, maybe the user or somene else removed it
+            // This is when there was a tile set and has disappear, maybe the user or someone else removed it
             if (tileSetBeforeLoad != tileSetAfterLoad) {
-                // warn the user tileset could not be loaded and the default one was loaded
+                // warn the user tile set could not be loaded and the default one was loaded
                 KMessageBox::information(this
-                           , i18nc("%1 is a path to a tileset file", "An error occurred when loading the tileset %1. The default tileset has been loaded.", tileSetBeforeLoad)
+                           , i18nc("%1 is a path to a tile set file", "An error occurred when loading the tile set %1. The default tile set has been loaded.", tileSetBeforeLoad)
                            , i18n("Error Loading Tiles")
                           );
             } else {
-                // neither the user tileset nor the default could be loaded
+                // neither the user tile set nor the default could be loaded
                 KMessageBox::error(this
-                           , i18nc("%1 is a path to a tileset file", "An error occurred when loading the tileset %1. The default tileset could also not be loaded.\nPlease install the KMahjongg library.", tileSetBeforeLoad)
+                           , i18nc("%1 is a path to a tile set file", "An error occurred when loading the tile set %1. The default tile set could also not be loaded.\nPlease install the KMahjongg library.", tileSetBeforeLoad)
                            , i18n("Error Loading Tiles")
                           );
             }
@@ -131,15 +103,15 @@ void Board::loadSettings()
                 );
             }
         } else {
-            // This is when there was a tileset and has disappear, maybe the user or somene else removed it
+            // This is when there was a background and has disappear, maybe the user or someone else removed it
             if (backgroundBeforeLoad != backgroundAfterLoad) {
-                // warn the user tileset could not be loaded and the default one was loaded
+                // warn the user background could not be loaded and the default one was loaded
                 KMessageBox::information(this
                            , i18nc("%1 is a path to a background image file", "An error occurred when loading the background %1. The default background has been loaded.", backgroundBeforeLoad)
                            , i18n("Error Loading Tiles")
                           );
             } else {
-                // neither the user tileset nor the default could be loaded
+                // neither the user background nor the default could be loaded
                 KMessageBox::error(this
                            , i18nc("%1 is a path to a background image  file", "An error occurred when loading the background %1. The default background could also not be loaded.\nPlease install the KMahjongg library.", backgroundBeforeLoad)
                            , i18n("Error Loading Tiles")
@@ -316,7 +288,7 @@ void Board::mousePressEvent(QMouseEvent * e)
     // Clicking on one of the already connected tiles would have selected
     // it before removing it. This is more a workaround than a proper fix
     // but I have to understand the usage of m_paintConnection first in
-    // order to consider its reusage here. (schwarzer)
+    // order to consider its reuse here. (schwarzer)
     if (m_paintInProgress) {
         return;
     }
@@ -1236,8 +1208,8 @@ int Board::findPath(TilePos tilePos1, TilePos tilePos2, PossibleMoves & possible
     }
 
     // Find paths of 3 segments
-    std::array<int, 4> constexpr dx {{1, 0, -1, 0}};
-    std::array<int, 4> constexpr dy {{0, 1, 0, -1}};
+    std::array constexpr dx {1, 0, -1, 0};
+    std::array constexpr dy {0, 1, 0, -1};
 
     for (auto i = 0; i < 4; ++i) {
         auto tempX = tilePos1.x() + dx.at(i);
@@ -1506,7 +1478,7 @@ void Board::undo()
             qCDebug(KSHISEN_General) << "[undo] gravity from slide s1(" << move->slideX1() << "," << move->slideY1() << ")=>s2(" << move->slideX2() << "," << move->slideY2() << ") matching (" << move->x1() << "," << move->y1() << ")=>(" << move->x2() << "," << move->y2() << ")";
 
             // horizontal slide
-            // because tiles that slides horizontaly may fall down
+            // because tiles that slides horizontally may fall down
             // in columns different than the taken tiles columns
             // we need to take them back up then undo the slide
             if (move->slideY1() == move->slideY2()) {
@@ -1761,7 +1733,7 @@ int Board::lineWidth() const
 
 bool Board::pathFoundBetweenMatchingTiles(PossibleMoves & possibleMoves) const
 {
-    std::array<short, Board::nTiles> done{}; // Appended {} initialises with zeroes here.
+    std::array<short, Board::nTiles> done{};
 
     for (decltype(xTiles()) x = 0; x < xTiles(); ++x) {
         for (decltype(yTiles()) y = 0; y < yTiles(); ++y) {
@@ -2034,5 +2006,7 @@ bool Board::isTileSeason(int tile) const
 }
 } // namespace KShisen
 
+#include "moc_board.cpp"
+
 // vim: expandtab:tabstop=4:shiftwidth=4
 // kate: space-indent on; indent-width 4
